@@ -256,21 +256,36 @@ class RKXMLRequest(XMLRequest):
                 if item[0].tag == "Guests":
                     order = item[1][0].attrib
                     order_dto = OrderListDTO(visit_id=visit.get('VisitID'),
-                                             order_id=order.get('OrderID'), count_guest=visit.get('GuestsCount'),
-                                             order_name=order.get('OrderName'), url=(order.get('Url')),
-                                             version=order.get('Version'), crc32=order.get('Crc32'),
-                                             guid=order.get('guid'), table_id=(order.get('TableID')),
+                                             order_id=order.get('OrderID'),
+                                             count_guest=visit.get(
+                                                 'GuestsCount'),
+                                             order_name=order.get('OrderName'),
+                                             url=(order.get('Url')),
+                                             version=order.get('Version'),
+                                             crc32=order.get('Crc32'),
+                                             guid=order.get('guid'),
+                                             table_id=(order.get('TableID')),
                                              table_code=order.get('TableCode'),
                                              order_categ_id=order.get(
                                                  'OrderCategId'),
-                                             order_categ_code=order.get('OrderCategCode'), bill=order.get('Bill'),
+                                             order_categ_code=order.get(
+                                                 'OrderCategCode'),
+                                             bill=order.get('Bill'),
                                              waiter_id=order.get('WaiterID'),
                                              order_type_code=order.get(
                                                  'OrderTypeCode'),
-                                             order_type_id=order.get('OrderTypeID'), to_pay_sum=order.get('ToPaySum'),
-                                             waiter_code=order.get('WaiterCode'), order_sum=order.get('OrderSum'),
-                                             total_pieces=order.get('TotalPieces'), finished=order.get('Finished'),
-                                             price_list_sum=order.get('PriceListSum'), dessert=order.get('Dessert'),
+                                             order_type_id=order.get(
+                                                 'OrderTypeID'),
+                                             to_pay_sum=order.get('ToPaySum'),
+                                             waiter_code=order.get(
+                                                 'WaiterCode'),
+                                             order_sum=order.get('OrderSum'),
+                                             total_pieces=order.get(
+                                                 'TotalPieces'),
+                                             finished=order.get('Finished'),
+                                             price_list_sum=order.get(
+                                                 'PriceListSum'),
+                                             dessert=order.get('Dessert'),
                                              created_time=order.get(
                                                  'CreateTime'),
                                              finished_time=order.get('FinishTime'))
@@ -448,7 +463,8 @@ class RKXMLRequest(XMLRequest):
                 for modi in order.findall('./Session/Dish/Modi'):
                     modi_item = modi.attrib
                     order_obj = OrderLineDTO(
-                        guid=order_item.get('guid'),
+                        order_guid=order_item.get('guid'),
+                        line_guid=attr_of_item_node.get('line_guid'),
                         dish_id=attr_of_item_node.get('id'),
                         dish_name=attr_of_item_node.get('name'),
                         quantity=int(attr_of_item_node.get('quantity')) / 1000,
@@ -472,6 +488,7 @@ class RKXMLRequest(XMLRequest):
                     modi_item = modi.attrib
                     order_obj = OrderLineDTO(
                         order_guid=order_item.get('guid'),
+                        line_guid=attr_of_item_node.get('line_guid'),
                         dish_id=attr_of_item_node.get('id'),
                         dish_name=attr_of_item_node.get('name'),
                         quantity=int(attr_of_item_node.get('quantity')) / 1000,
